"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_1 = require("@oclif/command");
const chalk_1 = tslib_1.__importDefault(require("chalk"));
const path_1 = tslib_1.__importDefault(require("path"));
const createAppDir_1 = require("../utils/createAppDir");
const checkAppDir_1 = require("../utils/checkAppDir");
const createApp_1 = require("../utils/createApp");
const createPkgFile_1 = require("../utils/createPkgFile");
const install_1 = require("../utils/install");
const showTips_1 = require("../utils/showTips");
class New extends command_1.Command {
    async run() {
        const { args } = this.parse(New);
        const appName = args.appName;
        if (!appName) {
            return this.log(chalk_1.default.red('required project name, eg: dh new myapp'));
        }
        const root = path_1.default.resolve(appName);
        try {
            createAppDir_1.createAppDir(root);
            checkAppDir_1.checkAppDir(root, appName);
            await createApp_1.createApp(root);
            createPkgFile_1.createPkgFile(root, appName);
            await install_1.install(root);
            showTips_1.showTips(root, appName);
        }
        catch (error) {
            this.log(error);
        }
    }
}
New.description = 'Create a new Dahlia app';
New.aliases = ['n'];
New.examples = [`$ dh new myapp`];
New.args = [{ name: 'appName' }];
exports.default = New;
