"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const fs_extra_1 = tslib_1.__importDefault(require("fs-extra"));
const fs_jetpack_1 = tslib_1.__importDefault(require("fs-jetpack"));
const paths_1 = require("./paths");
const formatCode_1 = require("./formatCode");
function last(arr) {
    return arr[arr.length - 1];
}
function capitalizeFirstLetter(str) {
    return str.charAt(0).toUpperCase() + str.slice(1);
}
function getModalName(path = '') {
    const fileName = last(path.split('/'));
    const modalName = fileName.replace(/\.tsx$/, '');
    return modalName;
}
function getCmpName(path = '') {
    const fileName = last(path.split('/'));
    const modalName = fileName.replace(/\.tsx$/, '').replace(/[\.\-\^\$]/g, '_');
    return capitalizeFirstLetter(modalName);
}
function formatModals(modals) {
    return modals.map(item => {
        const modalName = getModalName(item);
        const cmpName = getCmpName(item);
        const modalImportPath = item
            .replace(/^modals/, '../../modals')
            .replace(/\.tsx$/, '');
        return {
            modalName,
            cmpName,
            modalImportPath,
        };
    });
}
function getModalsConfig(modals) {
    const modalArr = formatModals(modals);
    const importFiles = modalArr
        .map(item => {
        return `import ${item.cmpName} from '${item.modalImportPath}'`;
    })
        .join('\n');
    const modalsString = modalArr
        .map(item => {
        return `{
  name: '${item.modalName}',
  component: ${item.cmpName},
},`;
    })
        .join('\n');
    return `
${importFiles}

const modals = [
  ${modalsString}
]

export default modals;
    `;
}
function writeFile(text) {
    fs_extra_1.default.writeFileSync(paths_1.tmpModalsConfigPath, text, { encoding: 'utf8' });
}
function writeFileFromModalsFile() {
    const routesConfig = fs_extra_1.default.readFileSync(paths_1.modalConfigPath, { encoding: 'utf8' });
    const text = routesConfig
        .replace(/\.\.\/modals/g, '../../modals')
        .replace(/\.\.\/layouts/g, '../../layouts')
        .replace(/@modals/g, '../../modals');
    writeFile(text);
}
exports.createModalConfig = () => {
    fs_extra_1.default.ensureDirSync(paths_1.tmpConfigDir);
    if (fs_extra_1.default.existsSync(paths_1.modalConfigPath)) {
        writeFileFromModalsFile();
        return;
    }
    const modals = fs_extra_1.default.existsSync(paths_1.modalsDir)
        ? fs_jetpack_1.default.find(paths_1.modalsDir, { matching: '**/*.tsx' })
        : [];
    const modasText = getModalsConfig(modals);
    const code = formatCode_1.formatCode(modasText);
    writeFile(code);
};
