"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const fs_extra_1 = tslib_1.__importDefault(require("fs-extra"));
const fs_jetpack_1 = tslib_1.__importDefault(require("fs-jetpack"));
const paths_1 = require("./paths");
const formatCode_1 = require("./formatCode");
function last(arr) {
    return arr[arr.length - 1];
}
function capitalizeFirstLetter(str) {
    return str.charAt(0).toUpperCase() + str.slice(1);
}
function getPageName(path = '') {
    const fileName = last(path.split('/'));
    const pageName = fileName.replace(/\.tsx$/, '').replace(/[\.\-\^\$]/g, '_');
    return capitalizeFirstLetter(pageName);
}
function formatPages(pages) {
    return pages.map(item => {
        const HOME_PAGE = 'pages/index.tsx';
        let routerPath;
        const pageName = getPageName(item);
        const pageImportPath = item
            .replace(/^pages/, '../../pages')
            .replace(/\.tsx$/, '');
        if (item === HOME_PAGE) {
            routerPath = '/';
        }
        else {
            routerPath = item.replace(/^pages/, '').replace(/\.tsx$/, '');
        }
        return {
            pageName,
            pageImportPath,
            routerPath,
        };
    });
}
function getRoutesConfig(pages) {
    const pagesArr = formatPages(pages);
    const importFiles = pagesArr
        .map(item => {
        return `import ${item.pageName} from '${item.pageImportPath}'`;
    })
        .join('\n');
    const routesString = pagesArr
        .map(item => {
        return `{
  path: '${item.routerPath}',
  component: ${item.pageName},
},`;
    })
        .join('\n');
    return `
${importFiles}

const routes = [
  ${routesString}
]

export default routes;
    `;
}
function writeFile(text) {
    fs_extra_1.default.writeFileSync(paths_1.tmpRouterConfigPath, text, { encoding: 'utf8' });
}
function writeFileFromRoutesFile() {
    const routesConfig = fs_extra_1.default.readFileSync(paths_1.routerConfigPath, { encoding: 'utf8' });
    const text = routesConfig
        .replace(/\.\.\/pages/g, '../../pages')
        .replace(/\.\.\/layouts/g, '../../layouts')
        .replace(/@pages/g, '../../pages')
        .replace(/@layouts/g, '../../layouts');
    writeFile(text);
}
exports.createRouterConfig = () => {
    fs_extra_1.default.ensureDirSync(paths_1.tmpConfigDir);
    if (fs_extra_1.default.existsSync(paths_1.routerConfigPath)) {
        writeFileFromRoutesFile();
        return;
    }
    const pages = fs_jetpack_1.default.find(paths_1.pagesDir, { matching: '**/*.tsx' });
    const routesText = getRoutesConfig(pages);
    const code = formatCode_1.formatCode(routesText);
    writeFile(code);
};
