"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const formatCode_1 = require("./formatCode");
const htmlText = formatCode_1.formatCode(`
<!DOCTYPE html>
<html lang="en">
  <head>
    <meta charset="utf-8">
    <link rel="shortcut icon" href="%PUBLIC_URL%/favicon.ico">
    <meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no">
    <meta name="theme-color" content="#000000">
    <link rel="manifest" href="%PUBLIC_URL%/manifest.json">
    <title>%TITLE%</title>
  </head>
  <body>
    <noscript>
      You need to enable JavaScript to run this app.
    </noscript>
    <div id="root"></div>
  </body>
</html>
`, 'html');
exports.entryText = formatCode_1.formatCode(`
import Dahlia, { Config } from 'dahlia'
import { ResponseInterceptor } from 'dahlia/rest'
import { modalStore } from 'dahlia/modal'

import configDefault from './config/config.default'
import configLocal from './config/config.local'
import configProd from './config/config.prod'
import routes from './config/router.config'
import modals from './config/modal.config'
import response from './interceptors/response'
import App from './common/App'
import Modal from './common/Modal'

const responseInterceptors: ResponseInterceptor[] = Array.isArray(response)
  ? response
  : [response]

const { NODE_ENV } = process.env

const config = {
  routes,
  modals,
  graphql: {
    endpoint: '/graphql',
  },
  rest: {
    endpoint: location.protocol + '//' + location.host,
  },
  root: '#root',
  app: App,
} as Config

// customize modal
modalStore.setModalContainer(Modal)

const isProd = NODE_ENV === 'production'

const userConfig = isProd
  ? { ...configDefault, ...configProd }
  : { ...configDefault, ...configLocal }

const finalConfig = {
  ...config,
  ...userConfig,
} as Config

finalConfig.rest.interceptor = {} as any
finalConfig.rest.interceptor.responses = responseInterceptors

const lang = localStorage.getItem('__lang__') || 'default'

import('./locales/' + lang + '.json')
  .then(i => {
    ;(window as any).__locale__ = i.default
    Dahlia.bootstrap(finalConfig)
  })
  .catch(() => {
    Dahlia.bootstrap(finalConfig)
  })

`);
const interceptor = formatCode_1.formatCode(`
export default (data: any) => {
  return data
}
`);
const config = formatCode_1.formatCode(`
const config = {
}
export default config
`);
exports.default = {
    entry: exports.entryText,
    html: htmlText,
    interceptor,
    config,
};
